<template>
    <div class="screen-header">
        <div class="header-left-wrapper"></div>
        <div class="header-center-wrapper flex-between">
            <div class="btn-group btn-group-left flex-end"></div>
            <div class="sys-info flex-center">
                <img class="logo" :src="logoUrl" />
                <div class="title">
                    {{ AITitle }}
                </div>
            </div>
            <div class="btn-group btn-group-right flex-start"></div>
        </div>
        <div class="header-right-wrapper">
            <!-- <div class="tool-weather" :title="weathernow">
                <img class="weather-icon" :src="weatherIcon" alt="image" />
                {{ weathernow }}
            </div>
            <span class="line"></span> -->
            <div class="tool-day">{{ daynow }}</div>
            <span class="line"></span>
            <div class="tool-time">{{ timenow }}</div>

            <div class="logout" @click="handleHomePage" title="首页">
                <img src="../../assets/img/bigScreen/icon-logout.png" />
            </div>
        </div>
    </div>
</template>



<script>
import commomAPI from '@/api/bigScreen/common.js'
import routerManagement from '@/api/BasicDataManagement/tollStationManagement.js'
import utils from '@/utils'
import moment from 'moment'
export default {
    name: 'bigScreen',
    props: {
        AITitle: {
            type: String,
            required: true,
        },
    },
    data() {
        return {
            sysName: '',
            logoUrl: '',
            timenow: '',
            daynow: '',
            weathernow: '',
            weatherIcon: '',
            hournow: '',
            timer: null,
        }
    },
    mounted() {
        this.getSysInfo()
        this.getTimeNow()
        // this.getWeather()
    },
    activated() {},
    methods: {
        // 获取系统信息
        getSysInfo() {
            let sysinfo = sessionStorage.getItem('sysinfo')
            if (sysinfo) {
                sysinfo = JSON.parse(sysinfo)
                this.logoUrl = sysinfo.logoUrl
                this.sysName = sysinfo.sysName
            } else {
                let url =
                    '${uc}/uc/tenantManage/v1/getTenantByCode?code=platform'
                this.$http.get(url).then((resp) => {
                    if (resp.data) {
                        let tenantManage = resp.data
                        this.sysName = tenantManage.nameFront
                        if (tenantManage.frontLogo) {
                            let frontLogo = JSON.parse(tenantManage.frontLogo)
                            if (frontLogo && frontLogo.length > 0) {
                                this.logoUrl =
                                    window.context.portal +
                                    '/file/onlinePreviewController/v1/getFileById_' +
                                    frontLogo[0].id

                                let sysinfo = {
                                    logoUrl: this.logoUrl,
                                    sysName: this.sysName,
                                }
                                sessionStorage.setItem(
                                    'sysinfo',
                                    JSON.stringify(sysinfo)
                                )
                            }
                        }
                    }
                })
            }
        },
        getWeather() {
            let ss = sessionStorage.getItem('weathernow')
            if (ss) {
                this.getWeatherIcon(JSON.parse(ss))
            } else {
                commomAPI
                    .queryWeather()
                    .then((res) => {
                        console.log('res', res)
                        // console.log('获取的数据' + res.data.lives[0].weather)
                        this.weathernow = res.data.lives[0].weather
                        this.getWeatherIcon(this.weathernow)
                        sessionStorage.setItem(
                            'weathernow',
                            JSON.stringify(this.weathernow)
                        )
                    })
                    .catch((err) => {
                        console.log('err', err)
                    })
            }
        },
        // 退出登陆
        handleHomePage() {
            this.$router.push({
                path: '/homePage',
            })
        },
        // 实时获取
        getTimeNow() {
            this.daynow = moment().format('YYYY年MM月DD日')
            this.timenow = moment().format('HH:mm:ss')
            this.timer = setInterval(() => {
                this.timenow = moment().format('HH:mm:ss')
            }, 1000)
        },
        clear() {
            clearInterval(this.timer)
        },
        // 获取天气icon
        getWeatherIcon(weather) {
            this.hournow = moment().format('hh') // 获取时间 判断半天黑夜
            this.weathernow = weather
            if (
                this.hournow > 6 &&
                this.hournow < 19 &&
                this.weathernow == '晴'
            ) {
                this.weatherIcon = require('@/assets/img/weather/qing.png')
            } else if (
                this.hournow > 6 &&
                this.hournow < 19 &&
                this.weathernow == '多云的'
            ) {
                this.weatherIcon = require('@/assets/img/weather/duoyun.png')
            } else if (this.weathernow == '阴') {
                this.weatherIcon = require('@/assets/img/weather/yin.png')
            } else if (this.weathernow == '霾') {
                this.weatherIcon = require('@/assets/img/weather/yin.png')
            } else if (this.weathernow == '雷阵雨') {
                this.weatherIcon = require('@/assets/img/weather/leizhenyu.png')
            } else if (this.weathernow == '雨') {
                this.weatherIcon = require('@/assets/img/weather/xiaoyu.png')
            } else if (this.weathernow == '小雨') {
                this.weatherIcon = require('@/assets/img/weather/xiaoyu.png')
            } else if (this.weathernow == '中雨') {
                this.weatherIcon = require('@/assets/img/weather/zhongyu.png')
            } else if (this.weathernow == '大雨') {
                this.weatherIcon = require('@/assets/img/weather/dayu.png')
            } else if (this.weathernow == '暴雨') {
                this.weatherIcon = require('@/assets/img/weather/baoyu.png')
            } else if (this.weathernow == '大暴雨') {
                this.weatherIcon = require('@/assets/img/weather/baoyu.png')
            } else if (
                this.weathernow == '中雨-大雨' ||
                this.weathernow == '小雨-中雨' ||
                this.weathernow == '大雨-暴雨' ||
                this.weathernow == '暴雨-大暴雨'
            ) {
                this.weatherIcon = require('@/assets/img/weather/dayu.png')
            } else if (this.weathernow.indexOf('风') != -1) {
                this.weatherIcon = require('@/assets/img/weather/dafeng.png')
            } else if (
                this.hournow < 6 &&
                this.hournow > 19 &&
                this.weathernow == '多云都'
            ) {
                this.weatherIcon = require('@/assets/img/weather/duoyunye.png')
            } else if (
                this.hournow < 6 &&
                this.hournow > 19 &&
                this.weathernow == '晴'
            ) {
                this.weatherIcon = require('@/assets/img/weather/qingye.png')
            } else {
                this.weatherIcon = require('@/assets/img/weather/yin.png')
            }
        },
        beforeDestroy() {
            this.clear()
        },
    },
}
</script>

<style lang="scss" scoped>

.screen-header{
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 80px;
    line-height: 80px;
    display: flex;
    background: url('../../assets/img/bigScreen/nav-bg.png') no-repeat center / 100%;
    z-index: 999;
}
.header-center-wrapper{
    width: 1160px;
    .btn-group{
        width: 330px;
        .menu-item{
            width: 172px;
            height: 55px;
            display: flex;
            justify-content: center;
            align-items: center;
            cursor: pointer;
            span{
                font-size: 16px;
                font-weight: 400;
                color: #fff;
                margin-top: 4px;
            }
        }
    }
    .btn-group-left{
        .menu-item:nth-of-type(1){
            margin-right: -25px;
        }
        .menu-item{
            background: url('../../assets/img/bigScreen/nav-btn-left.png') no-repeat center / 100%;
            span{
                margin-left: 10px;
            }
        }
        .menu-item:hover,.menu-item.active{
            background: url('../../assets/img/bigScreen/nav-btn-left-active.png') no-repeat center / 100%;
            span{
                font-weight: bold;
            }
        }
    }
    .btn-group-right{
        .menu-item:nth-of-type(2){
            margin-left: -25px;
        }
        .menu-item{
            background: url('../../assets/img/bigScreen/nav-btn-right.png') no-repeat center / 100%;
            span{
                margin-right: 10px;
            }
        }
        .menu-item:hover,.menu-item.active{
            background: url('../../assets/img/bigScreen/nav-btn-right-active.png') no-repeat center / 100%;
            span{
                font-weight: bold;
            }
        }
    }
    .sys-info{
        gap: 8px;
        .logo{
            width: 50px;
            height: 50px;
        }
        .title{
            font-size: 34px;
            color: #fff;
            font-weight: bold;
            font-family: PingFang SC;
        }
    }
}
.header-left-wrapper,.header-right-wrapper{
    width: 380px;
    display: flex;
    box-sizing: border-box;
}
.header-left-wrapper{
    padding-left: 16px;
    justify-content: flex-start;
    align-items: center;
    gap: 10px;
    /deep/.el-input__inner {
        background-color: transparent;
        color: #FFFFFF;
        border:1px solid #2C4E91;
        text-align: center;
        font-size: 16px;
        font-weight: 700;
    }
    
    /deep/.el-input__prefix{
        left: 10px;
        
    }
    /deep/.el-input__icon{
        font-size: 16px;
        color: #fff;
    }

}
.header-right-wrapper{
    justify-content: flex-end;
    align-items: center;
    padding-right: 16px;
}


.tool-weather{
    height: 23px; 
    font-size: 14px;
    font-weight: 400;
    line-height: 23px;
    text-align: center;
    color: #FFFFFF;
    display: flex;
    align-items: center;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
}
.tool-day{
    height: 30px;
    font-size: 12px;
    font-weight: 400;
    color: #FFFFFF;
    line-height: 30px;
}

.line{
    display: inline-block;
    box-sizing: border-box;
    width: 1px;
    height: 10px;
    background: #B2B2B2;
    margin:0 8px;
}
.tool-time{ 
    height: 30px;
    font-size: 18px;
    font-weight: 700;
    color: #FFFFFF;
    line-height: 30px;
    font-family: PingFang SC;
}
.sys, .logout{
    width: 32px;
    height: 38px;
    margin-left: 16px;
    display: flex;
    align-items: center;
    justify-content: center;
    cursor: pointer;
    img{
        width: 100%;
        height: 100%;
    }
}

.company-name{
  width: 150px;
  height: 100%;
  margin-left: 16px;
}
.company-name img{
    width: 146px;
    height: 34px;
    margin-top: 13px;
}
.system-name{
  width: 180px;
  height: 100%;
  margin-left: 20px;
}
.system-name img{
    width: 180px;
    height: 100%;

}
.desk-menu{
    width: 900px;
    height: 100%;
    margin-left: 112px;
    display: flex;
    font-size: 18px;
    font-weight: 400;
}
.desk-menu-list{
    width: 150px;
    height: 100%;
    text-align: center;
    line-height: 60px;
    font-size: 18px;
    color: #fff;
    cursor: pointer;
    margin-top: 2px;
    background: url('../../assets/img/bigScreen/bg-list.png') no-repeat center / 158px 63px;
}
.desk-normal{
    width: 150px;
    height: 100%;
    text-align: center;
    line-height: 60px;
    font-size: 18px;
    color: #fff;
    cursor: pointer;
    margin-top: 2px;
    background: url('../../assets/img/bigScreen/bg-list.png') no-repeat center / 158px 63px;
}
.choose{
    /* background-color:#fbfbfb ; */
    color: #fff;
    font-weight: 700;
    margin-top: 2px;
    background: url('../../assets/img/bigScreen/bg-list-actived.png') no-repeat center / 158px 63px;
}

.weather-icon{
  width: 20px;
  height: 20px;
  margin-right: 5px;
}

.sysmenu-container-mask{
    position: absolute;
    left: 0;
    top: 0;
    width: 100vw;
    height: 100vh;
}
.sysmenu-container{
    position: absolute;
    width: 80%;
    height: 0;
    opacity: 0;
    top: 80px;
    left: 10%;
    backdrop-filter: blur(5px);
    background: linear-gradient(360deg, rgba(7,17,29,0.8) 0%, rgba(7,17,29,0.4) 100%);
    box-shadow: 0px 5px 20px 0px #4DA6FF;
    border-radius: 0px 0px 16px 16px;
    border: 2px solid;
    overflow: hidden;
    border-image: linear-gradient(90deg, rgba(204, 229, 255, 0), rgba(204, 229, 255, 1), rgba(255, 255, 255, 0)) 2 2;
    transition: all 0.3s linear;
}
.sysmenu-container.show{
    height: 120px;
    opacity: 1;
}
.sysmenu-container{
    .menu-item{
        width: 224px;
        height: 58px;
        line-height: 58px;
        text-align: center;
        color: #E5F2FF;
        font-size: 18px;
        border:2px solid transparent;
        cursor: pointer;
    }
    .menu-item.active,.menu-item:hover{
        background: rgba(38,83,128,0.47);
        box-shadow: inset 0px 0px 10px 0px #3399FF;
        border-radius: 8px 8px 8px 8px;
        border:2px solid #3399ff;
        font-weight: 700;
        color: #FFFFFF;
    }
}
.header-toll-search{
    /deep/ .el-select-dropdown,.el-popper{
        background-color:rgba(27, 27, 27, 0.4);
        backdrop-filter: blur(10px);
        border: 1px solid #2C4E91;
    }
    .el-select-dropdown__item{
        color: #fff;
    }
    .el-select-dropdown__item.hover, .el-select-dropdown__item:hover {
        background-color: rgba(51, 153, 255, 0.3);
        color: #53a9ff;
    }
    /deep/.el-popper[x-placement^="bottom"] .popper__arrow {
        border-bottom-color: #7d95cf;
    }
    /deep/.el-popper[x-placement^="bottom"] .popper__arrow::after {
        border-bottom-color: #2C4E91;
    }
}
.header-date-search-input.el-date-editor.el-input{
    width: 180px!important;
}
</style>
<style lang='scss'>
.header-date-search{
    &.el-picker-panel{
        background: rgba(27, 27, 27, 0.4)!important;
        backdrop-filter: blur(10px);
        border: 1px solid #2C4E91;
    }
    &.el-popper[x-placement^="bottom"] .popper__arrow {
        border-bottom-color: #7d95cf;
    }
    &.el-popper[x-placement^="bottom"] .popper__arrow::after {
        border-bottom-color: #2C4E91;
    }
    .el-date-picker__header--bordered {
        border-bottom: solid 1px #2C4E91;
    }
    .el-date-picker__header-label,.el-month-table td .cell,.el-picker-panel__icon-btn,.el-year-table td .cell{
        color: #fff;
    }
    .el-date-picker__header-label:hover,.el-month-table td .cell:hover,.el-picker-panel__icon-btn:hover,.el-year-table td .cell:hover{
        color: #3399ff;
    }
    
}
</style>